@@ -1,9 +1,7 @@
-# coding=utf-8
-#
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2019 David R. MacIver
+# Most of this work is copyright (C) 2013-2020 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
 # CONTRIBUTING.rst for a full list of people who may hold copyright, and
 # consult the git log if you need to determine who owns an individual
@@ -15,32 +13,32 @@
 #
 # END HEADER
 
-from __future__ import absolute_import, division, print_function
-
-from collections import OrderedDict
+from collections import OrderedDict, abc
 from copy import copy
+from typing import Any, List, Sequence, Set, Union
 
 import attr
 import numpy as np
 import pandas
 
-import hypothesis._strategies as st
-import hypothesis.extra.numpy as npst
-import hypothesis.internal.conjecture.utils as cu
 from hypothesis.control import reject
 from hypothesis.errors import InvalidArgument
-from hypothesis.internal.compat import abc, hrange
+from hypothesis.extra import numpy as npst
+from hypothesis.internal.conjecture import utils as cu
 from hypothesis.internal.coverage import check, check_function
+from hypothesis.internal.reflection import deprecated_posargs
 from hypothesis.internal.validation import (
     check_type,
     check_valid_interval,
     check_valid_size,
     try_convert,
 )
+from hypothesis.strategies._internal import core as st
+from hypothesis.strategies._internal.strategies import Ex
 
 try:
     from pandas.api.types import is_categorical_dtype
-except ImportError:  # pragma: no cover
+except ImportError:
 
     def is_categorical_dtype(dt):
         if isinstance(dt, np.dtype):
@@ -48,11 +46,6 @@ except ImportError:  # pragma: no cover
         return dt == "category"
 
 
-if False:
-    from typing import Any, List, Union, Sequence, Set  # noqa
-    from hypothesis.searchstrategy.strategies import Ex  # noqa
-
-
 def dtype_for_elements_strategy(s):
     return st.shared(
         s.map(lambda x: pandas.Series([x]).dtype),
@@ -121,7 +114,7 @@ def elements_and_dtype(elements, dtype, source=None):
 
 class ValueIndexStrategy(st.SearchStrategy):
     def __init__(self, elements, dtype, min_size, max_size, unique):
-        super(ValueIndexStrategy, self).__init__()
+        super().__init__()
         self.elements = elements
         self.dtype = dtype
         self.min_size = min_size
@@ -160,8 +153,9 @@ DEFAULT_MAX_SIZE = 10
 
 @st.cacheable
 @st.defines_strategy
-def range_indexes(min_size=0, max_size=None):
-    # type: (int, int) -> st.SearchStrategy[pandas.RangeIndex]
+def range_indexes(
+    min_size: int = 0, max_size: int = None
+) -> st.SearchStrategy[pandas.RangeIndex]:
     """Provides a strategy which generates an :class:`~pandas.Index` whose
     values are 0, 1, ..., n for some n.
 
@@ -181,13 +175,15 @@ def range_indexes(min_size=0, max_size=None):
 
 @st.cacheable
 @st.defines_strategy
+@deprecated_posargs
 def indexes(
-    elements=None,  # type: st.SearchStrategy[Ex]
-    dtype=None,  # type: Any
-    min_size=0,  # type: int
-    max_size=None,  # type: int
-    unique=True,  # type: bool
-):
+    *,
+    elements: st.SearchStrategy[Ex] = None,
+    dtype: Any = None,
+    min_size: int = 0,
+    max_size: int = None,
+    unique: bool = True
+) -> st.SearchStrategy[pandas.Index]:
     """Provides a strategy for producing a :class:`pandas.Index`.
 
     Arguments:
@@ -220,14 +216,15 @@ def indexes(
 
 
 @st.defines_strategy
+@deprecated_posargs
 def series(
-    elements=None,  # type: st.SearchStrategy[Ex]
-    dtype=None,  # type: Any
-    index=None,  # type: st.SearchStrategy[Union[Sequence, pandas.Index]]
-    fill=None,  # type: st.SearchStrategy[Ex]
-    unique=False,  # type: bool
-):
-    # type: (...) -> st.SearchStrategy[pandas.Series]
+    *,
+    elements: st.SearchStrategy[Ex] = None,
+    dtype: Any = None,
+    index: st.SearchStrategy[Union[Sequence, pandas.Index]] = None,
+    fill: st.SearchStrategy[Ex] = None,
+    unique: bool = False
+) -> st.SearchStrategy[pandas.Series]:
     """Provides a strategy for producing a :class:`pandas.Series`.
 
     Arguments:
@@ -264,7 +261,7 @@ def series(
     if index is None:
         index = range_indexes()
     else:
-        st.check_strategy(index)
+        st.check_strategy(index, "index")
 
     elements, dtype = elements_and_dtype(elements, dtype)
     index_strategy = index
@@ -311,7 +308,7 @@ def series(
 
 
 @attr.s(slots=True)
-class column(object):
+class column:
     """Data object for describing a column in a DataFrame.
 
     Arguments:
@@ -335,14 +332,15 @@ class column(object):
     unique = attr.ib(default=False)
 
 
+@deprecated_posargs
 def columns(
-    names_or_number,  # type: Union[int, Sequence[str]]
-    dtype=None,  # type: Any
-    elements=None,  # type: st.SearchStrategy[Ex]
-    fill=None,  # type: st.SearchStrategy[Ex]
-    unique=False,  # type: bool
-):
-    # type: (...) -> List[column]
+    names_or_number: Union[int, Sequence[str]],
+    *,
+    dtype: Any = None,
+    elements: st.SearchStrategy[Ex] = None,
+    fill: st.SearchStrategy[Ex] = None,
+    unique: bool = False
+) -> List[column]:
     """A convenience function for producing a list of :class:`column` objects
     of the same general shape.
 
@@ -362,13 +360,14 @@ def columns(
     ]
 
 
+@deprecated_posargs
 @st.defines_strategy
 def data_frames(
-    columns=None,  # type: Sequence[column]
-    rows=None,  # type: st.SearchStrategy[Union[dict, Sequence[Any]]]
-    index=None,  # type: st.SearchStrategy[Ex]
-):
-    # type: (...) -> st.SearchStrategy[pandas.DataFrame]
+    columns: Sequence[column] = None,
+    *,
+    rows: st.SearchStrategy[Union[dict, Sequence[Any]]] = None,
+    index: st.SearchStrategy[Ex] = None
+) -> st.SearchStrategy[pandas.DataFrame]:
     """Provides a strategy for producing a :class:`pandas.DataFrame`.
 
     Arguments:
@@ -474,7 +473,7 @@ def data_frames(
     if index is None:
         index = range_indexes()
     else:
-        st.check_strategy(index)
+        st.check_strategy(index, "index")
 
     index_strategy = index
 
@@ -578,7 +577,7 @@ def data_frames(
                     )
                 seen = {c.name: set() for c in columns_without_fill if c.unique}
 
-                for i in hrange(len(index)):
+                for i in range(len(index)):
                     for c in columns_without_fill:
                         if c.unique:
                             for _ in range(5):
@@ -635,8 +634,8 @@ def data_frames(
                 while all_seen[-1] is None:
                     all_seen.pop()
 
-            for row_index in hrange(len(index)):
-                for _ in hrange(5):
+            for row_index in range(len(index)):
+                for _ in range(5):
                     original_row = draw(rows)
                     row = original_row
                     if isinstance(row, dict):
